@@ -14,6 +14,7 @@
 extern "C" {
 #endif
 
+#include <netinet/in.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <stddef.h>
@@ -85,7 +86,8 @@ enum WIFIGETDATA
 /// Initializes WiFi library.
 ///
 /// It initializes the WiFi hardware, sets up a FIFO handler to communicate with
-/// the ARM7 side of the library, and it sets up timer 3 to be used by DSWiFi.
+/// the ARM7 side of the library. The ARM7 sets up timer number
+/// LIBNDS_DEFAULT_TIMER_WIFI to be used by DSWiFi.
 ///
 /// You can pass a few options depending on your needs:
 ///
@@ -250,7 +252,10 @@ enum WIFI_ASSOCSTATUS
     ASSOCSTATUS_AUTHENTICATING,
     /// Connecting...
     ASSOCSTATUS_ASSOCIATING,
-    /// Connected to AP, but getting IP data from DHCP
+    /// Connected to AP, but getting IP data from DHCP. This will finish when we
+    /// have an IPv4 or IPv6 address, it doesn't wait for both to be available.
+    /// Normally the IPv4 address is available first. Use Wifi_GetIPv6() to
+    /// verify if you have an IPv6 address or not.
     ASSOCSTATUS_ACQUIRINGDHCP,
     /// Connected! (COMPLETE if Wifi_ConnectAP was called to start)
     ASSOCSTATUS_ASSOCIATED,
@@ -350,6 +355,11 @@ int Wifi_ConnectAP(Wifi_AccessPoint *apdata, int wepmode, int wepkeyid, unsigned
 
 /// Connect to an Access Point.
 ///
+/// That this function forces you to specify the password manually. If the AP
+/// is configured in the WFC settings the library will ignore the saved data
+/// and it will use the information passed to this function. If you want to use
+/// the saved WFC settings you have to use Wifi_ConnectWfcAP().
+///
 /// @param apdata
 ///     Basic data about the AP. The user must fill either the bssid field or
 ///     the ssid and ssid_len fields. Other fields are ignored.
@@ -364,6 +374,27 @@ int Wifi_ConnectAP(Wifi_AccessPoint *apdata, int wepmode, int wepkeyid, unsigned
 ///     0 for ok, -1 for error with input data.
 int Wifi_ConnectSecureAP(Wifi_AccessPoint *apdata, const void *key, size_t key_len);
 
+/// Connect to an AP that has been configured in the WFC settings.
+///
+/// This is useful if multiple APs have been configured but you want to let the
+/// user select which AP to connect to. It can also be useful if you want to
+/// prioritize APs with better security settings, like connecting to WPA2 APs
+/// instead of open ones. Wifi_AutoConnect() would make the library connect to
+/// the first known AP it finds regardless of the security settings.
+///
+/// Note that this function doesn't let you specify the password manually. If
+/// the AP isn't configured in the WFC settings the library will enter "cannot
+/// connect" state. If you want to use a password other than the WFC settings,
+/// use Wifi_ConnectSecureAP().
+///
+/// @param apdata
+///     Basic data about the AP. The user must fill either the ssid and ssid_len
+///     fields. Other fields are ignored.
+///
+/// @return
+///     0 for ok, -1 for error with input data.
+int Wifi_ConnectWfcAP(Wifi_AccessPoint *apdata);
+
 /// Connect to an AP without encryption (and NDS multiplayer hosts).
 ///
 /// @param apdata
@@ -698,9 +729,20 @@ void Wifi_InternetMode(void);
 /// manually.
 ///
 /// @return
-///     The current IP address of the DS
+///     The current IP address of the DS or INADDR_NONE on error.
 u32 Wifi_GetIP(void);
 
+/// It returns an array of 4 u32 values with the current IPv6 address of the DS.
+///
+/// The IP may not be valid before connecting to an AP.
+///
+/// @param
+///     addr The struct to be filled with the IPv6 address.
+///
+/// @return
+///     If there is a valid IPv6 address it returns true. Otherwise, false.
+bool Wifi_GetIPv6(struct in6_addr *addr);
+
 /// Returns IP information.
 ///
 /// The values may not be valid before connecting to an AP, or setting the IP
