@@ -167,12 +167,22 @@ typedef enum
     GL_AMBIENT_AND_DIFFUSE = 0x03,
     /// Specular color for the material. The glossy (highlight) color of the polygon.
     GL_SPECULAR            = 0x04,
+
     /// Shininess color for the material. The color that shines back to the user.
+    ///
+    /// @warning
+    ///     This has no effect.
     GL_SHININESS           = 0x08,
+
     /// Emission color for the material. Color independent of normals and lights.
     GL_EMISSION            = 0x10
 } GL_MATERIALS_ENUM;
 
+/// Use shininess table for specular materials.
+///
+/// See glMaterialShininess().
+#define GL_SPECULAR_USE_TABLE BIT(15)
+
 /// Polygon rendering attributes.
 ///
 /// Related functions: glPolyFmt(), glInit(), POLY_ALPHA(), POLY_ID()
@@ -357,9 +367,14 @@ typedef enum
 /// Related functions: glEnable(), glDisable(), glInit()
 enum GLFLUSH_ENUM
 {
-    /// Enable manual sorting of translucent polygons, otherwise uses Y-sorting
+    /// Enable automatic Y-sorting of translucent polygons
+    GL_TRANS_YSORT      = (0 << 0),
+    /// Enable manual sorting of translucent polygons
     GL_TRANS_MANUALSORT = (1 << 0),
-    /// Enable W depth buffering of vertices, otherwise uses Z depth buffering
+
+    /// Use Z depth buffering of vertices
+    GL_ZBUFFERING       = (0 << 1),
+    /// Use W depth buffering of vertices (don't use for orthogonal projections)
     GL_WBUFFERING       = (1 << 1)
 };
 
@@ -1012,8 +1027,13 @@ static inline void glFlush(u32 mode)
     GFX_FLUSH = mode;
 }
 
-/// The DS uses a table for shininess. This generates one.
-static inline void glMaterialShinyness(void)
+/// Generate a linear table of values for GL_SPECULAR materials.
+///
+/// You need to enable it by doing this, for example:
+/// ```c
+/// glMaterial(GL_SPECULAR, RGB(31, 31, 31) | GL_SPECULAR_USE_TABLE);
+/// ```
+static inline void glMaterialShininess(void)
 {
     /* More optimized version of the following:
 
@@ -1032,6 +1052,13 @@ static inline void glMaterialShinyness(void)
         GFX_SHININESS = v;
 }
 
+/// Old name of the function
+__attribute__((deprecated))
+static inline void glMaterialShinyness(void)
+{
+    glMaterialShininess();
+}
+
 /// Set the parameters for polygons rendered on the current frame.
 ///
 /// Valid paramters are enumerated in GL_POLY_FORMAT_ENUM and in the functions
@@ -1446,7 +1473,7 @@ void glGetFixed(const GL_GET_ENUM param, int *f);
 /// Polygons with a lower alpha value won't be displayed.
 ///
 /// @param alphaThreshold
-///     Minimum alpha value that will be used (0 - 15).
+///     Minimum alpha value that will be used (0 - 31).
 static inline void glAlphaFunc(int alphaThreshold)
 {
     GFX_ALPHA_TEST = alphaThreshold;
@@ -1471,6 +1498,12 @@ static inline void glCutoffDepth(fixed12d3 wVal)
 ///     1 on success, 0 on failure
 int glInit(void);
 
+/// Deinitializes the GL state machine and frees all memory used by it.
+///
+/// @return
+///     1 on success, 0 on failure
+int glDeinit(void);
+
 /// Sets the color of the rear-plane (a.k.a clear color/plane)
 ///
 /// @param red
