@@ -220,10 +220,19 @@ u32 systemSetBacklightLevel(u32 level);
 ///
 /// This returns a value with two fields. Bits 0 to 3 are the battery level,
 /// and bit 7 is set to 1 if an external power source is connected to the DS.
+/// You can use the defines BATTERY_LEVEL_MASK and BATTERY_CHARGER_CONNECTED to
+/// make your code more readable:
+///
+/// ```
+/// u32 value = getBatteryLevel();
+/// unsigned int battery_level = value & BATTERY_LEVEL_MASK;
+/// bool charger_connected = value & BATTERY_CHARGER_CONNECTED;
+/// ```
 ///
 /// On DSi the battery level is the one reported by the hardware. On DS, the
 /// battery level is only "high" or "low", and libnds returns 15 or 3
-/// respectively as the equivalent DSi battery level.
+/// respectively as the equivalent DSi battery level. You can use defines
+/// BATTERY_LEVEL_DS_HIGH and BATTERY_LEVEL_DS_LOW instead.
 ///
 /// @note
 ///     When called from the ARM9, this function requests the battery
@@ -234,6 +243,17 @@ u32 systemSetBacklightLevel(u32 level);
 ///     Battery level and external power source status.
 u32 getBatteryLevel(void);
 
+/// This is set if the charger is connected. See getBatteryLevel().
+#define BATTERY_CHARGER_CONNECTED   BIT(7)
+
+/// Mask to get the actual battery level from getBatteryLevel().
+#define BATTERY_LEVEL_MASK          0xF
+
+/// Value that corresponds to high battery level on a DS (green LED).
+#define BATTERY_LEVEL_DS_HIGH       0xF
+/// Value that corresponds to low battery level on a DS (red LED).
+#define BATTERY_LEVEL_DS_LOW        0x3
+
 // Helper functions for heap size
 
 /// Returns current start of heap space.
@@ -703,9 +723,20 @@ struct __bootstub {
     u32 bootsize;
 };
 
-// This is 0x23F4000 on NDS and 0x2FF4000 on DSi. However, on NDS 0x2FF4000 is a
-// mirror of 0x23F4000.
-#define __system_bootstub ((struct __bootstub *)0x02FF4000)
+// The boot stub is stored at 0x2FF4000. However, on the ARM9 side, DTCM is
+// made available through this location, overlaping the boot stub data.
+// As such, it has to be accessed through a mirror:
+//
+// - On the DS, 0x27F4000 is used - this covers both debugger units (on
+//   which this is at the end of the cached RAM area) and retail units
+//   (on which this is the first of three RAM mirrors).
+// - On the DSi, 0xCFF4000 is used - this is a distinct area where the
+//   main memory is made available.
+#ifdef ARM9
+#define __system_bootstub ((struct __bootstub *) (isDSiMode() ? 0x0CFF4000 : 0x027F4000))
+#else
+#define __system_bootstub ((struct __bootstub *) 0x02FF4000)
+#endif
 
 #ifdef ARM9
 /// Returns a cached mirror of an address.
